@@ -36,7 +36,7 @@ class ResponseViewMixin(object):
         )
 
         queryset = self.model_class.all()
-        if hasattr(self.model_class, 'is_delete'):
-            return queryset.filter(is_delete=False)
+        if hasattr(self.model_class, 'is_active'):
+            return queryset.filter(is_active=True)
         else:
             return queryset
