@@ -7,12 +7,17 @@
 # @FileName: views.py
 # @Software: PyCharm
 """
-from starlette.responses import JSONResponse
+from starlette.requests import Request
+from starlette.responses import JSONResponse, RedirectResponse
 
 from .schemas import schemas
 from starlette_utils.response import api_endpoints
 
 
+async def swagger_view(request: Request, *args, **kwargs):
+    return RedirectResponse(url='/static/swagger/index.html')
+
+
 class OpenApi(api_endpoints.RetrieveApiView):
     routes = []
 
